<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":                                    $messaggio = "Preis&auml;nderungen f&uuml;r"; break;
case "Prezzi della":                                                     $messaggio = "Preise von"; break;
case "tariffa":                                                          $messaggio = "Preis"; break;
case "soprannominata":                                                   $messaggio = "Bezeichnung"; break;
case "Dal":                                                              $messaggio = "von"; break;
case "al":                                                               $messaggio = "zu"; break;
case "inserisci i nuovi prezzi":                                         $messaggio = "Neue Preise &uuml;bernehmen"; break;
case "modifica i prezzi già inseriti":                                   $messaggio = "Bereits eingef&uuml;gte Preise ver&auml;ndern"; break;
case "Costi aggiuntivi":                                                 $messaggio = "Zuschl&auml;ge"; break;
case "Nome del nuovo costo aggiuntivo":                                  $messaggio = "Neue Bezeichnung f&uuml;r einen Zuschlag"; break;
case "da applicare":                                                     $messaggio = "anzuwenden"; break;
case "sempre":                                                           $messaggio = "immer"; break;
case "su richiesta":                                                     $messaggio = "auf Anforderung"; break;
case "chiedi per quanto deve essere moltiplicato":                       $messaggio = "fragen wie oft es multipliziert werden mu&szlig;"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":            $messaggio = "verwende diese Einmalkosten wie Zusatzbett(en)"; break;
case "numero di settimane":                                              $messaggio = "Anzahl der Wochen"; break;
case "numero di giorni":                                                 $messaggio = "Anzahl der Tage"; break;
case "tutte":                                                            $messaggio = "alle"; break;
case "tutti":                                                            $messaggio = "alle"; break;
case "tutte meno una":                                                   $messaggio = "alle minus einem"; break;
case "tutti meno uno":                                                   $messaggio = "alle minus einem"; break;
case "chiedere":                                                         $messaggio = "fragen"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":       $messaggio = "verwende diese w&ouml;chentlichen Zuschl&auml;ge wie Zusatzbett(en)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":       $messaggio = "verwende diese t&auml;glichen Zuschl&auml;ge wie Zusatzbett(en)"; break;
case "della tariffa arrotondato a":                                      $messaggio = "des Preises gerundet zu"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":       $messaggio = "verwende diese prozentualen Zuschl&auml;ge wie Zusatzbett(en)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":              $messaggio = "Einf&uuml;gen des neuen Zuschlages"; break;
case "Caparra":                                                          $messaggio = "Anzahlung"; break;
case "arrotondata a":                                                    $messaggio = "gerundet zu"; break;
case "Inserisci o modifica la caparra":                                  $messaggio = "Eingeben oder &auml;ndern der Anzahlung"; break;
case "Vedi i prezzi già inseriti":                                       $messaggio = "Bisher eingegebene Preise anzeigen"; break;
case "Torna al menù principale":                                         $messaggio = "Zum Hauptmen&uuml;"; break;
case "Si deve inserire la percentuale":                                  $messaggio = "Sie m&uuml;ssen den Prozentsatz angeben"; break;
case "La caparra è stata modificata":                                    $messaggio = "Die Anzahlung wurde ge&auml;ndert"; break;
case "Si deve specificare quando applicare il costo di fine locazione":  $messaggio = "Sie m&uuml;ssen ausw&auml;hlen wie die Einmalkosten angewendet werden sollen"; break;
case "Si deve inserire il nome del costo aggiuntivo":                    $messaggio = "Sie m&uuml;ssen den Namen des Zuschlags eingeben"; break;
case "Il costo aggiuntivo finale":                                       $messaggio = "Einmalige Zuschl&auml;ge"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":        $messaggio = "existiert bereits, gehen Sie zu der Seite mit den Zeitr&auml;umen und Preisen um Sie zu l&ouml;schen."; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":        $messaggio = "Um zu fragen wie oft es multipliziert werden mu&szlig; d&uuml;rfen die einmaligen Zuschl&auml;ge nicht automatisch angewendet werden."; break;
case "Si deve specificare quando applicare il costo settimanale":        $messaggio = "Sie m&uuml;ssen ausw&auml;hlen wie die w&ouml;chentlichen Kosten angewendet werden sollen"; break;
case "Si deve specificare quando applicare il costo giornaliero":        $messaggio = "Sie m&uuml;ssen ausw&auml;hlen wie die t&auml;glichen Kosten angewendet werden sollen"; break;
case "e il numero di settimane":                                         $messaggio = "und die Anzahl der Wochen"; break;
case "e il numero di giorni":                                            $messaggio = "und die Anzahl der Tage"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":        $messaggio = "Um zu fragen wie oft es multipliziert werden mu&szlig; d&uuml;rfen die w&ouml;chentlichen Zuschl&auml;ge nicht automatisch angewendet werden."; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":        $messaggio = "Um zu fragen wie oft es multipliziert werden mu&szlig; d&uuml;rfen die t&auml;glichen Zuschl&auml;ge nicht automatisch angewendet werden."; break;
case "Il costo aggiuntivo settimanale":                                  $messaggio = "Die w&ouml;chentlichen Zuschl&auml;ge"; break;
case "Il costo aggiuntivo giornaliero":                                  $messaggio = "Die t&auml;glichen Zuschl&auml;ge"; break;
case "Si deve specificare quando applicare il costo percentuale":        $messaggio = "Sie m&uuml;ssen ausw&auml;hlen wie die prozentualen Kosten angewendet werden sollen"; break;
case "e il valore dell'arrotondamento":                                  $messaggio = "und der Wert gerundet zu"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":        $messaggio = "Um zu fragen wie oft es multipliziert werden mu&szlig; d&uuml;rfen die prozentualen Zuschl&auml;ge nicht automatisch angewendet werden."; break;
case "Il costo aggiuntivo percentuale":                                  $messaggio = "Die prozentualen Zuschl&auml;ge"; break;
case "è stato inserito":                                                 $messaggio = "wurden eingetragen"; break;
case "Il soprannome della":                                              $messaggio = "Der Name von"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":        $messaggio = "existiert bereits, benutzen Sie den Butten \"&Auml;ndern von bestehenden Preisen\" um es zu &auml;ndern oder tragen Sie nichts ein um Preise in neuen Zeitr&auml;umen anzugeben."; break;
case "Il soprannome":                                                    $messaggio = "Der Name"; break;
case "già esiste, ne devi usare un'altro":                               $messaggio = "existiert bereits, benutzen Sie einen anderen."; break;
case "Le date del periodo numero":                                       $messaggio = "Die Daten des Zeitraumes Nummer"; break;
case "sono sbagliate":                                                   $messaggio = "sind falsch"; break;
case "Il periodo":                                                       $messaggio = "Der Zeitraum"; break;
case "si sovrappone ad un periodo precedente":                           $messaggio = "&uuml;berschneidet sich mit einem anderen"; break;
case "Un prezzo nel periodo numero":                                     $messaggio = "Ein Preis im Zeitraum Nummer"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":        $messaggio = "existiert bereits, benutzen Sie den Knopf \"&Auml;ndern bereits existierender Preise\" um ihn zu &auml;ndern."; break;
case "è stato cambiato":                                                 $messaggio = "wurde ge&auml;ndert"; break;
case "Il prezzo del periodo":                                            $messaggio = "Die Preise des Zeitraumes"; break;
case "è stato inserito":                                                 $messaggio = "wurden eingetragen"; break;
case "Il prezzo del periodo numero":                                     $messaggio = "Der Preis des Zeitraumes Nummer"; break;
case "è sbagliato":                                                      $messaggio = "ist falsch"; break;
case "I soldi del costo finale sono sbagliati":                          $messaggio = "Der Betrag f&uuml;r die Einmalkosten ist falsch"; break;
case "I soldi del costo settimanale sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die w&ouml;chentlichen Zuschl&auml;ge ist falsch"; break;
case "I soldi del costo giornaliero sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die t&auml;glichen Zuschl&auml;ge ist falsch"; break;
case "I soldi del costo percentuale sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die prozentualen Zuschl&auml;ge ist falsch"; break;
case "Inserzione per settimane":                                         $messaggio = "Tarif&auml;nderung auf w&ouml;chentlicher Basis"; break;
case "Inserzione per giorni":			$messaggio = "Preise auf t&auml;glicher Basis"; break;
case "Inserzione per settimane":  		$messaggio = "Preise auf w&ouml;chentlicher Basis"; break;
case "Settimane dal":                                                    $messaggio = "Wochen von"; break;
case "Dom/Lun":                                                          $messaggio = "So/Mo"; break;
case "Lun/Mar":                                                          $messaggio = "Mo/Di"; break;
case "Mar/Mer":                                                          $messaggio = "Di/Mi"; break;
case "Mer/Gio":                                                          $messaggio = "Mi/Do"; break;
case "Gio/Ven":                                                          $messaggio = "Do/Fr"; break;
case "Ven/Sab":                                                          $messaggio = "Fr/Sa"; break;
case "Sab/Dom":                                                          $messaggio = "Sa/So"; break;
case "inserisci o modifica i prezzi":                                    $messaggio = "Eintragen oder &auml;ndern der Preise"; break;
case "Le date sono sbagliate":                                           $messaggio = "Daten sind falsch"; break;
case "Il formato dei soldi è sbagliato":                                 $messaggio = "W&auml;hrungsformat ist falsch"; break;
case "I prezzi per le settimane dal":                                    $messaggio = "Die Preise f&uuml;r die Wochen von"; break;
case "della <b>tariffa":                                                 $messaggio = "des <b>Preises"; break;
case "sono stati inseriti":                                              $messaggio = "wurde eingetragen"; break;
case "si":                                                               $messaggio = "Ja"; break;
case "no":                                                               $messaggio = "Nein"; break;
case "assegnato automaticamente con tariffe":                            $messaggio = "automatisch angewendet f&uuml;r Preise"; break;
case "nessuna":                                                          $messaggio = "keinen"; break;
case "scegliere":                                                        $messaggio = "ausw&auml;hlen"; break;
case "mostrare nella pagina di inserzione prenotazioni":                 $messaggio = "Auf der Seite zum Eintragen von Reservierungen anzeigen"; break;
case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
case "Continua":                                                         $messaggio = "Weiter"; break;
case "Tipo di costo aggiuntivo":                                         $messaggio = "H&auml;ufigkeit des Zuschlages"; break;
case "unico":                                                            $messaggio = "einmalig"; break;
case "settimanale":                                                      $messaggio = "w&ouml;chentlich"; break;
case "giornaliero":                                                      $messaggio = "t&auml;glich"; break;
case "il prezzo totale":                                                 $messaggio = "des Gesamtpreises"; break;
case "la caparra":                                                       $messaggio = "die Anzahlung"; break;
case "totale meno caparra":                                              $messaggio = "Gesamtpreis ohne Anzahlung"; break;
case "minimo":                                                           $messaggio = "minimal"; break;
case "massimo":                                                          $messaggio = "maximal"; break;
case "esattamente":                                                      $messaggio = "genau"; break;
case "settimane":                                                        $messaggio = "Wochen"; break;
case "giorni":                                                           $messaggio = "Tage"; break;
case "Se possibile":                                                     $messaggio = "Wenn m&ouml;glich"; break;
case "Sempre":                                                           $messaggio = "Immer"; break;
case "Associare a specifiche settimane della prenotazione":              $messaggio = "Besonderen Wochen der Reservierung zuweisen"; break;
case "Associare a specifici giorni della prenotazione":                  $messaggio = "Besonderen Tagen der Reservierung zuweisen"; break;
case "Tutte":                                                            $messaggio = "Alle"; break;
case "Tutti":                                                            $messaggio = "Alle"; break;
case "Tutte meno":                                                       $messaggio = "Alle minus"; break;
case "Tutti meno":                                                       $messaggio = "Alle minus"; break;
case "la prima":                                                         $messaggio = "der erste"; break;
case "il primo":                                                         $messaggio = "der erste"; break;
case "l'ultima":                                                         $messaggio = "der letzte"; break;
case "l'ultimo":                                                         $messaggio = "der letzte"; break;
case "Chiedere":                                                         $messaggio = "Fragen"; break;
case "settimane sì":                                                     $messaggio = "Wochen ja"; break;
case "giorni sì":                                                        $messaggio = "Tage ja"; break;
case "settimane no":                                                     $messaggio = "Wochen nein"; break;
case "giorni no":                                                        $messaggio = "Tage nein"; break;
case "e":                                                                $messaggio = "und"; break;
case "Giorni della settimana selezionati":                               $messaggio = "Ausgew&auml;hlte Wochentage"; break;
case "Lunedì":                                                           $messaggio = "Montag"; break;
case "Martedì":                                                          $messaggio = "Dienstag"; break;
case "Mercoledì":                                                        $messaggio = "Mittwoch"; break;
case "Giovedì":                                                          $messaggio = "Donnerstag"; break;
case "Venerdì":                                                          $messaggio = "Freitag"; break;
case "Sabato":                                                           $messaggio = "Sonnabend"; break;
case "Domenica":                                                         $messaggio = "Sonntag"; break;
case "Moltiplicare il costo per":                                        $messaggio = "Kosten multiplizieren mit"; break;
case "Uno":                                                              $messaggio = "Eins"; break;
case "Chiedere":                                                         $messaggio = "Fragen"; break;
case "Numero di persone":                                                $messaggio = "Personenanzahl"; break;
case "Numero di persone totale":                                         $messaggio = "Gesamtpersonenzahl"; break;
case "escluse quelle dei costi con letti aggiuntivi":                    $messaggio = "ohne diejenigen Personen in Zusatzbetten"; break;
case "Periodi in cui è permesso inserire il costo":                      $messaggio = "Zeitr&auml;ume in denen die Zuschl&auml;ge angewendet werden d&uuml;rfen"; break;
case "In tutti":                                                         $messaggio = "Alle"; break;
case "Solo nei periodi selezionati":                                     $messaggio = "Nur ausgew&auml;hlte Zeitr&auml;ume"; break;
case "dal":                                                              $messaggio = "von"; break;
case "Elimina un periodo":                                               $messaggio = "Zeitraum entfernen"; break;
case "Aggiungi un periodo":                                              $messaggio = "Zeitraum hinzuf&uuml;gen"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":        $messaggio = "wenn alle Wochen der Reservierung innerhalb der ausgew&auml;hlten Zeitr&auml;ume liegen"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":            $messaggio = "wenn alle Tage der Reservierung innerhalb der ausgew&auml;hlten Zeitr&auml;ume liegen"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":             $messaggio = "Zuschl&auml;ge nur in den zugelassenen Wochen der Reservierung anwenden"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":                $messaggio = "f&uuml;ge den Zuschlag nur an den zugelassenen Tagen hinzu"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":               $messaggio = "Folgende Eigenschaften der Kosten sind beizubehalten, wenn eine Reservierung ge&auml;ndert wird:"; break;
case "Valore percentuale":                                               $messaggio = "Prozentwert"; break;
case "e settimane associate":                                            $messaggio = "und damit verkn&uuml;pfte Wochen"; break;
case "e giorni associati":                                               $messaggio = "und damit verkn&uuml;pfte Tage"; break;
case "Assegnazione settimane":                                           $messaggio = "Zuweisung einzelner Wochen"; break;
case "Assegnazione giorni":                                              $messaggio = "Zuweisung einzelner Tage"; break;
case "Numero per cui viene moltiplicato":                                $messaggio = "Zahl mit der es zu multiplizieren ist"; break;
case "Periodi permessi":                                                 $messaggio = "Zugelassene Zeitr&auml;ume"; break;
case "Associazione alle tariffe":                                        $messaggio = "Zuweisung von Tarifen"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":          $messaggio = "Auf der Seite zum Eintragen von Reservierungen anzeigen"; break;
case "Si":                                                               $messaggio = "Ja"; break;
case "No":                                                               $messaggio = "Nein"; break;
case "Considerare il costo come letto/i aggiuntivo/i":                   $messaggio = "Diese Zuschl&auml;ge wie Zusatzbett(en) betrachten"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":        $messaggio = "Die Gesamtzahl der angewendeten Zuschl&auml;ge innerhalb eines Zeitraums begrenzen"; break;
case "Valore del costo":                                                 $messaggio = "Betrag des Zuschlages"; break;
case "fisso di":                                                         $messaggio = "fest"; break;
case "percentuale su":                                                   $messaggio = "Prozentsatz"; break;
case "la tariffa":                                                       $messaggio = "der Tarif"; break;
case "indietro":                                                         $messaggio = "zur&uuml;ck"; break;
case "avanti":                                                           $messaggio = "weiter"; break;
case "del":                                                              $messaggio = "von"; break;
case "arrotondato a":                                                    $messaggio = "gerundet auf"; break;
case "Errore nei valori inseriti":                                       $messaggio = "Fehler in den eingef&uuml;gten Werten"; break;
case "Assegnare automaticamente con le tariffe selezionate":             $messaggio = "Mit den ausgew&auml;hlten Tarifen zuweisen"; break;
case "Tariffe":                                                          $messaggio = "Tarif"; break;
case "Il costo aggiuntivo":                                              $messaggio = "Der Zuschlag"; break;
case "OK":                                                               $messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":                            $messaggio = "Wochen, an denen der Zuschlag anzuwenden ist"; break;
case "I giorni a cui applicare il costo":                                $messaggio = "Tage, an denen der Zuschlag anzuwenden ist"; break;
case "uno":                                                              $messaggio = "eins"; break;
case "NO":                                                               $messaggio = "NEIN"; break;
case "SI":                                                               $messaggio = "JA"; break;
case "Tariffe incompatibili con il costo":                               $messaggio = "Preise mit Zuschlag nicht kompatibel"; break;
case "Tariffe incompatibili":                                            $messaggio = "Unvertr&auml;gliche Tarife"; break;
case "dalla":                                                            $messaggio = "von"; break;
case "aggiungendo":  				                         $messaggio = "und addieren"; break;
case "I prezzi della tariffa selezionata sono stati importati":          $messaggio = "Die Preise des ausgew&auml;hlten Tarifs wurden importiert"; break;
case "importa":                                                          $messaggio = "importieren"; break;
case "se selezionato mantenere anche":                                   $messaggio = "wenn ausgew&auml;hlt au&szlig;erdem beibehalten"; break;
case "Quando possibile assegna automaticamente se mancano":              $messaggio = "Sofern m&ouml;glich automatisch zuweisen, wenn"; break;
case "meno di":                                                          $messaggio = "weniger als"; break;
case "più di":                                                          $messaggio = "mehr als"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita": $messaggio = "Tage zwischen Buchungs- und Reservierungsdatum liegen."; break;
case "Quando possibile assegna automaticamente se si inseriscono":       $messaggio = "Sofern m&ouml;glich automatisch zuweisen, wenn"; break;
case "o più prenotazioni contemporaneamente":                           $messaggio = "oder mehr Reservierungen gleichzeitig angelegt werden"; break;
case "Modifica il costo":                                                $messaggio = "Kosten &auml;ndern"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":                     $messaggio = "Einen neuen Zuschlag anlegen mit dem Namen"; break;
case "importando le caratteristiche da":                                 $messaggio = "Einstellungen importieren von"; break;
case "Sempre in periodi permessi":                                       $messaggio = "Immer, wenn zugelassen"; break;
case "Prezzo dell'intera settimana":                                     $messaggio = "Preis je Woche"; break;
case "Prezzi dei giorni":                                                $messaggio = "Preis je Tag"; break;
case "tra":                                                              $messaggio = "zwischen"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":   $messaggio = "zu l&ouml;schende Artikel nach Zimmerabrechnung"; break;
case "Nessuno":                                                          $messaggio = "keine"; break;
case "Beni selezionati":                                                 $messaggio = "gew&auml;hlte Artikel"; break;
case "Aggiungi un bene":                                                 $messaggio = "Artikel hinzuf&uuml;gen"; break;
case "Elimina un bene":                                                  $messaggio = "Artikel entfernen"; break;
case "elimina i beni dall'inventario del magazzino":                     $messaggio = "Artikel l&ouml;schen nach Abrechnung des Lagers"; break;
case "Beni dell'inventario da eliminare":                                $messaggio = "Artikelabrechnung zum l&ouml;schen"; break;
case "Il tipo di applicazione della":                                    $messaggio = "Den Ausf&uuml;hrungstype w&auml;hlen"; break;
case "per persona":                                                      $messaggio = "je Person"; break;
case "per settimana":                                                    $messaggio = "je Woche"; break;
case "per giorno":                                                       $messaggio = "pro Tag"; break;
case "La caparra è errata":                                             $messaggio = "Die Anzahlung ist falsch"; break;
case "è":                                                               $messaggio = "ist"; break;
case "il":                                                               $messaggio = "auf"; break;
case "Commissioni":                                                      $messaggio = "Nachl&auml;sse"; break;
case "sono":                                                             $messaggio = "wird"; break;
case "Inserisci o modifica le commissioni":                              $messaggio = "speichern der Nachl&auml;sse"; break;
case "Tasse":                                                            $messaggio = "Steuern"; break;
case "della tariffa":                                                    $messaggio = "zum Satz von"; break;
case "Inserisci o modifica le tasse":                                    $messaggio = "speichern der Steuern"; break;
case "Le commissioni sono state modificate":                             $messaggio = "Kommissionen wurden ge&auml;ndert"; break;
case "Le commissioni sono errate":                                       $messaggio = "Kommission sind falsch"; break;
case "Le tasse sono state modificate":                                   $messaggio = "Steuern wurden ge&auml;ndert"; break;
case "Le tasse sono errate":                                             $messaggio = "Steuern sind falsch"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":  $messaggio = "Alle genannten Preise beeinhalten Steuer"; break;
case "Inserisci o modifica le commissioni normali":                      $messaggio = "Einf&uuml;gen und &auml;ndern der Kommission"; break;
case "Inserisci o modifica le commissioni in questo periodo":            $messaggio = "Einf&uuml;gen und &auml;ndern der Kommission in der aktuellen Abrechnung"; break;
case "Sulla":                                                            $messaggio = "Ein"; break;
case "al giorno":                                                        $messaggio = "je Tag"; break;
case "alla settimana":                                                   $messaggio = "je Woche"; break;
case "il valore del costo si intente con tasse già incluse":             $messaggio = "Die Kosten beeinhalten die Steuer"; break;
case "Categoria":                                                        $messaggio = "Kategorie"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "entspricht dem Normalpreis f&uuml;r die ersten"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "entspricht dem Normalpreis f&uuml;r die ersten"; break;
case "della":  					$messaggio = "vom"; break;
case "tariffa + sconto":  			$messaggio = "Tarif + Rabatt"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "Tarif + Rabatt + Extrageb&uuml;hren"; break;
case "Nome della":  				$messaggio = "Name von"; break;
case "Cambia":  				$messaggio = "&Auml;ndern"; break;
case "prezzo per settimana":  			$messaggio = "Preis pro Woche"; break;
case "prezzo per giorno":  			$messaggio = "Preis pro Tag"; break;
case "prezzo per persona per settimana":  	$messaggio = "Preis pro Person und Woche"; break;
case "prezzo per persona per giorno":  		$messaggio = "Preis pro Person und Tag"; break;
case "p":  					$messaggio = "p"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Schnelles Einf&uuml;gen eines neuen Zuschlags f&uuml;r"; break;
case "permanenza minima":  			$messaggio = "Mindestaufenthalt"; break;
case "letto aggiuntivo":  			$messaggio = "Zusatzbett"; break;
case "offerta speciale":  			$messaggio = "Benutzerdefiniert"; break;
case "inserisci":  				$messaggio = "Einf&uuml;gen"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "Nessun dato è stato inserito":  		$messaggio = "No data has been inserted"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the rates to which apply automatically the <b>daily</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>percentage</b> extra cost"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one week of the reservation is in the selected periods"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one day of the reservation is in the selected periods"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>